<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="en">
    <head>
        <meta http-equiv="Content-type" content="text/html; charset=utf-8" />
        <title>Report</title>
        <link href="./zp-compressed.css" type="text/css" media="screen, print" rel="stylesheet" />
        <link href="./zp-print.css" type="text/css" media="print" rel="stylesheet" />
        <!--[if IE]>
        <link href="./zp-ie.css" type="text/css" media="screen" rel="stylesheet" />
        <![endif]-->
        <link href="./pastie.css" type="text/css" media="all" rel="stylesheet" />
        <style type="text/css">
            .sidebar {
                font-size: 11px;
            }

            p.intro {
                font-style: bold;
            }

            .content .padding {
                padding: 0 36px 0 0;
            }

            .item .padding {
                padding: 0 12px 0 0;
            }

            .list-item h2 {
                margin: 0;
                line-height: 27px;
            }

        </style>
    </head>
    <body>

        <div class="skip">
            <a href="#content" title="Go directly to page content">Go to page content</a>
        </div>

        <div class="zp-wrapper">
            <div class="zp-70 content">
                <div class="padding">
                    <h1 id="top">Dexy Run Report</h1>
                    <h2>Results of your Run</h2>
                    <br />
                    <p>This is a logfile to help you understand how dexy has processed your files and to assist with troubleshooting.</p>
                    <br />
                    <br />
                    <h3>Timing</h3>
                    <p>The total elapsed time for batch {{ batch.batch_id }} was {{ "%0.2f" % batch.elapsed() }} ({{ "%0.2f" % (float(batch.elapsed())/60)}} minutes).</p>

</pre>

<h1>10 Slowest Tasks</h1>
<hr />
<ul>
    {% for task in batch.tasks_by_elapsed() -%}
    {% if task and task.elapsed -%}
    <li>{{ "%0.3f" % task.elapsed }} - <a href="#{{ task.doc.websafe_key() }}">{{ task.key }}</a> ({{ task.content_source }})</li>
    {% endif -%}
    {% endfor -%}
</ul>

                    <h1>Documents</h1>

                    {% for doc in docs -%}
                    <hr />
                    <h2 id="{{ doc.websafe_key() }}">{{ doc.key }} &nbsp;&nbsp;&nbsp; <a href="#top">&uarr;</a></h2>
                    <br />
                    <h4>Arguments</h4>
<pre><code>
{% for k, v in doc.args.iteritems() -%}
{% if not k in ('wrapper', 'contents') -%}
{% if isinstance(v, dict) -%}
{{ k }}:
{% for kk, vv in v.iteritems() -%}
&nbsp;&nbsp;&nbsp;&nbsp;{{ kk }}: {{ vv }}
{% endfor -%}
{% else -%}
{{ k }}: {{ v }}
{% endif -%}
{% endif -%}
{% endfor -%}
</code></pre>

                    {% if len(doc.inputs) > 0 %}
                    <br />
                    <h4>Inputs</h4>
                    <ul>
                        {% for d in doc.children %}
                        <li><a href="#{{ d.websafe_key() }}">{{ d.key }}</a></li>
                        {% endfor %}
                    </ul>
                    {% endif %}

                    <br />
                    <h4>Artifacts</h4>
                    <table style="width: 800px; border: thin solid black; border-collapse: collapse;">
                        <tr><th>Key</th><th>Link</th><th>Elapsed</th><th>Run Type</th><th>Sections</th><th>wd</th></tr>
                        {% for a in doc.artifacts -%}
                        <tr>
                            <td style="padding-left: 10px; padding-right: 10px; border:thin solid black;">{{ a.key }}</td>
                            <td style="padding-left: 10px; padding-right: 10px; border:thin solid black;"><a href="../../{{ a.output_data.storage.data_file() }}">{{ a.output_data.storage.data_file() }}</a></td>
                            <td style="padding-left: 10px; padding-right: 10px; border:thin solid black; text-align:center;">{{ "%0.4f" % a.elapsed }}</td>
                            <td style="padding-left: 10px; padding-right: 10px; border:thin solid black;">{{ a.content_source }}</td>
                            <td style="padding-left: 10px; padding-right: 10px; border:thin solid black;">
                                {% if hasattr(a.output_data, 'keys') -%}
                                {% for k in a.output_data.keys() -%}
                                {{ k }}<br />
                                {% endfor -%}
                                {% endif -%}
                            </td>
                            <td style="padding-left: 10px; padding-right: 10px; border:thin solid black;">
                                {% if a.working_dir_exists() -%}
                                <a href="../../{{ a.working_dir() }}">wd</a>
                                {% endif -%}
                            </td>
                        </tr>
                        {% endfor -%}
                    </table>
                    <br />
                    {% for a in doc.artifacts -%}
                    {% if a.stdout -%}
                    <p><b>{{ a.key }} stdout</b></p>
                    {{ a.stdout }}
                    {% endif -%}
                    {% endfor -%}
                    <br />
                    <h4>Document Log</h4>
<pre>
{{ doc.logstream.getvalue() }}
</pre>
                    <br />
                    {% endfor %}
                </div>
            </div>

            <div class="zp-30 sidebar">
                <h2>List of Documents</h2>
                <div style="height:400px; overflow:auto;">
                <ul>
                    {% for doc in sorted(docs, key=attrgetter('key')) %}
                    <li><a href="#{{ doc.websafe_key() }}">{{ doc }}</a></li>
                    {% endfor %}
                </ul>
                </div>
            </div>
        </div>
    </body>
</html>
